Electron Microscopy Machine Learning (emicroml)
===============================================

``emicroml`` is a Python library for training machine learning models for
applications in microscopy.

Setting up emicroml
-------------------

For instructions on installing the ``emicroml`` library, see the
:ref:`installation_instructions_sec` page.

Learning how to use emicroml
----------------------------

For those new to the ``emicroml`` library, it is recommended that they take a
look at the :ref:`examples_sec` page, which contain code examples that show how
one can use the ``emicroml`` library. While going through the examples, readers
can consult the :ref:`reference_guide_sec` to understand what each line of code
is doing.

Reproducing data of preprints and published papers
--------------------------------------------------

arXiv:2509.01075 (2025)
~~~~~~~~~~~~~~~~~~~~~~~

The majority of the data presented in Ref. [Fitzpatrick1]_ can be reproduced by
running all of the examples listed on the page
:ref:`examples_modelling_cbed_distortion_estimation_sec`.

Contents
--------
.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/emicroml>
   examples
   literature
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
